/*
	file automatically generated by make_test_files.pl
	Fri Jun 14 15:21:42 2002
*/

/*****************************************************************************
 *                                                                           *
 *          UNURAN -- Universal Non-Uniform Random number generator          *
 *                                                                           *
 *****************************************************************************/
    
/**
 ** Tests for CSTD
 **/
    
/*---------------------------------------------------------------------------*/
#include "testunuran.h"
/*---------------------------------------------------------------------------*/
#ifdef T_CSTD
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* global variables                                                          */

static struct prng *urng;           /* uniform random number generator       */

static FILE *TESTLOG;               /* test log file                         */
static FILE *UNURANLOG;             /* unuran log file                       */

static int test_ok = TRUE;          /* all tests ok (boolean)                */
static int n_tests_failed;          /* number of failed tests                */

/*---------------------------------------------------------------------------*/

void test_new( void );
void test_set( void );
void test_get( void );
void test_chg( void );
void test_init( void );
void test_reinit( void );
void test_sample( void );
void test_validate( void );

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par );

int unur_cstd_set_verify( UNUR_PAR *par, int );

/*---------------------------------------------------------------------------*/


/* prototypes */

static int COMPARE_SAMPLE_SIZE = 500;
static int VIOLATE_SAMPLE_SIZE = 20;





/*---------------------------------------------------------------------------*/

int main()
{ 
	/* open log file for unuran and set output stream for unuran messages */
	UNURANLOG = fopen( "t_cstd_unuran.log","w" );
	abort_if_NULL( stderr,-1, UNURANLOG );
	unur_set_stream( UNURANLOG );

	/* open log file for testing */
	TESTLOG = fopen( "t_cstd_test.log","w" );
	abort_if_NULL( stderr,-1, TESTLOG );

	/* write header into log file */
  	{
		time_t started;  
		fprintf(TESTLOG,"\nUNURAN - Universal Non-Uniform RANdom number generator\n\n");
		if (time( &started ) != -1)
			fprintf(TESTLOG,"%s",ctime(&started));
		fprintf(TESTLOG,"\n====================================================\n\n");
	}

	/* set uniform random number generator */
	urng = prng_new("mt19937(2097)");
	unur_set_default_urng(urng);

	/* set default debugging flag */
	unur_set_default_debug(UNUR_DEBUG_ALL);

	/* start test */
	printf("cstd: ");

	/* run tests */
	test_new();
	test_set();
	test_get();
	test_chg();
	test_init();
	test_sample();
	test_reinit();
	test_validate();

	/* test finished */
	printf("\n");  fflush(stdout);

	/* close log files */
	fprintf(TESTLOG,"\n====================================================\n\n");
	if (test_ok)
		fprintf(TESTLOG,"All tests PASSED.\n");
	else
		fprintf(TESTLOG,"Test(s) FAILED.\n");

	fclose(UNURANLOG);
	fclose(TESTLOG);

	/* exit */
	exit( (test_ok) ? 0 : -1 );

} /* end of main */

/*---------------------------------------------------------------------------*/

void test_new (void)
{
	/* start test */
	printf("[new "); fflush(stdout);
	fprintf(TESTLOG,"\n[new]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_DISTR *distr = NULL;
   distr = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 31, (unur_cstd_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 31, UNUR_ERR_NULL );
unur_distr_free(distr);
}

/* invalid distribution type */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_discr_new(); 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 37, (unur_cstd_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 37, UNUR_ERR_DISTR_INVALID );
unur_distr_free(distr);
}

/* not a standard distribution */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_cont_new(); 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 43, (unur_cstd_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 43, UNUR_ERR_DISTR_INVALID );
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = new  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_new() */

/*---------------------------------------------------------------------------*/

void test_set (void)
{
	/* start test */
	printf("[set "); fflush(stdout);
	fprintf(TESTLOG,"\n[set]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_PAR   *par = NULL;
   par = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 53, (unur_cstd_set_variant(par,1)) );
n_tests_failed += check_errorcode( TESTLOG, 53, UNUR_ERR_NULL );
}

/* invalid parameter object */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   par = unur_arou_new(distr); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 61, (unur_cstd_set_variant(par,1)) );
n_tests_failed += check_errorcode( TESTLOG, 61, UNUR_ERR_PAR_INVALID );
free(par);
unur_distr_free(distr);
}

/* invalid parameters */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   distr = unur_distr_normal(NULL,0);
   par = unur_cstd_new(distr); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 70, (unur_cstd_set_variant(par,9999)) );
n_tests_failed += check_errorcode( TESTLOG, 70, UNUR_ERR_PAR_VARIANT );
free(par);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = set  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_set() */

/*---------------------------------------------------------------------------*/

void test_get (void)
{
	/* start test */
	printf("[get "); fflush(stdout);
	fprintf(TESTLOG,"\n[get]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = get  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_get() */

/*---------------------------------------------------------------------------*/

void test_chg (void)
{
	/* start test */
	printf("[chg "); fflush(stdout);
	fprintf(TESTLOG,"\n[chg]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid generator object */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double fpar[2] = {0.,1.};
   distr = unur_distr_normal(fpar,2);
   par = unur_arou_new(distr);
   unur_set_debug(par,0);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 87,    gen );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 90, (unur_cstd_chg_pdfparams(gen, fpar, 2)) );
n_tests_failed += check_errorcode( TESTLOG, 90, UNUR_ERR_GEN_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 93, (unur_cstd_chg_truncated(gen, 0., 1.)) );
n_tests_failed += check_errorcode( TESTLOG, 93, UNUR_ERR_GEN_INVALID );
unur_free(gen);
unur_distr_free(distr);
}

/* invalid parameters */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double fpar[2] = {4.,1.};
   distr = unur_distr_gamma(fpar,2);
   par = unur_cstd_new(distr);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 100,    gen );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 103, (unur_cstd_chg_pdfparams(gen,NULL,1)) );
n_tests_failed += check_errorcode( TESTLOG, 103, UNUR_ERR_NULL );

unur_errno = 0;
unur_cstd_chg_pdfparams(gen,fpar,UNUR_DISTR_MAXPARAMS+10);
n_tests_failed += check_errorcode( TESTLOG, 106, UNUR_ERR_DISTR_NPARAMS );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 109, (unur_cstd_chg_pdfparams(gen,fpar,-1)) );
n_tests_failed += check_errorcode( TESTLOG, 109, UNUR_ERR_DISTR_NPARAMS );
unur_free(gen);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = chg  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_chg() */

/*---------------------------------------------------------------------------*/

void test_init (void)
{
	/* start test */
	printf("[init "); fflush(stdout);
	fprintf(TESTLOG,"\n[init]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_PAR   *par = NULL;
   par = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 120, (unur_init( par )) );
n_tests_failed += check_errorcode( TESTLOG, 120, UNUR_ERR_NULL );
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = init  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_init() */

/*---------------------------------------------------------------------------*/

void test_reinit (void)
{
	/* start test */
	printf("[reinit "); fflush(stdout);
	fprintf(TESTLOG,"\n[reinit]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = reinit  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_reinit() */

/*---------------------------------------------------------------------------*/

void test_sample (void)
{
	/* start test */
	printf("[sample "); fflush(stdout);
	fprintf(TESTLOG,"\n[sample]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = sample  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_sample() */

/*---------------------------------------------------------------------------*/

void test_validate (void)
{
	UNUR_DISTR *distr[65];
	UNUR_PAR *par;
	UNUR_GEN *gen;
	int n_tests_failed = 0;
	double *darray;
	double fpm[10];

	/* start test */
	printf("[validate "); fflush(stdout);
	fprintf(TESTLOG,"\n[validate]\n");

	/* reset counter */
	n_tests_failed = 0;


/* distributions: 65 */
fpm[0] = 1.;
fpm[1] = 2.;
distr[0] = unur_distr_beta(fpm,2);


fpm[0] = 1.;
fpm[1] = 5.;
distr[1] = unur_distr_beta(fpm,2);


fpm[0] = 7.;
fpm[1] = 0.1;
distr[60] = unur_distr_beta(fpm,2);


fpm[0] = 0.7;
fpm[1] = 0.1;
distr[61] = unur_distr_beta(fpm,2);


fpm[0] = 7.;
fpm[1] = 0.1;
fpm[3] = -1.;
fpm[4] = 2.;
distr[62] = unur_distr_beta(fpm,4);


fpm[0] = 1.;
fpm[1] = 100.;
distr[2] = unur_distr_beta(fpm,2);


fpm[0] = 3.;
fpm[1] = 4.;
distr[3] = unur_distr_beta(fpm,2);


fpm[0] = 5.;
fpm[1] = 100.;
distr[4] = unur_distr_beta(fpm,2);


fpm[0] = 500.;
fpm[1] = 300.;
distr[5] = unur_distr_beta(fpm,2);


fpm[0] = 5.;
fpm[1] = 10.;
fpm[2] = -3.;
fpm[3] = 15.;
distr[6] = unur_distr_beta(fpm,4);


distr[7] = unur_distr_cauchy(NULL,0);


fpm[0] = 1.;
fpm[1] = 20.;
distr[8] = unur_distr_cauchy(fpm,2);


fpm[0] = 0.5;
distr[23] = unur_distr_chi(fpm,1);


fpm[0] = 1.;
distr[24] = unur_distr_chi(fpm,1);


fpm[0] = 2.;
distr[25] = unur_distr_chi(fpm,1);


fpm[0] = 50.;
distr[26] = unur_distr_chi(fpm,1);


distr[27] = unur_distr_exponential(NULL,0);


fpm[0] = 0.5;
distr[28] = unur_distr_exponential(fpm,1);


fpm[0] = 5.;
fpm[1] = -3.;
distr[29] = unur_distr_exponential(fpm,2);


distr[30] = unur_distr_extremeI(NULL,0);


fpm[0] = -3.;
distr[31] = unur_distr_extremeI(fpm,1);


fpm[0] = -1.;
fpm[1] = 5.;
distr[32] = unur_distr_extremeI(fpm,2);


fpm[0] = 3.;
distr[33] = unur_distr_extremeII(fpm,1);


fpm[0] = 0.5;
fpm[1] = -3.;
distr[34] = unur_distr_extremeII(fpm,2);


fpm[0] = 0.8;
fpm[1] = -1.;
fpm[2] = 5.;
distr[35] = unur_distr_extremeII(fpm,3);


fpm[0] = 1.;
distr[9] = unur_distr_gamma(fpm,1);


fpm[0] = 2.;
distr[10] = unur_distr_gamma(fpm,1);


fpm[0] = 3.;
distr[11] = unur_distr_gamma(fpm,1);


fpm[0] = 10.;
distr[12] = unur_distr_gamma(fpm,1);


fpm[0] = 1000.;
distr[13] = unur_distr_gamma(fpm,1);


fpm[0] = 5.;
fpm[1] = 1000.;
distr[14] = unur_distr_gamma(fpm,2);


fpm[0] = 5.;
fpm[1] = 1.e-5;
distr[15] = unur_distr_gamma(fpm,2);


fpm[0] = 5.;
fpm[1] = 10.;
fpm[2] = 1000;
distr[16] = unur_distr_gamma(fpm,3);


fpm[0] = 0.5;
distr[63] = unur_distr_gamma(fpm,1);


fpm[0] = 0.2;
distr[64] = unur_distr_gamma(fpm,1);


distr[36] = unur_distr_laplace(NULL,0);


fpm[0] = -3.;
distr[37] = unur_distr_laplace(fpm,1);


fpm[0] = -1.;
fpm[1] = 5.;
distr[38] = unur_distr_laplace(fpm,2);


distr[39] = unur_distr_logistic(NULL,0);


fpm[0] = -3.;
distr[40] = unur_distr_logistic(fpm,1);


fpm[0] = -1.;
fpm[1] = 5.;
distr[41] = unur_distr_logistic(fpm,2);


fpm[0] = 2.;
fpm[1] = 3.;
distr[56] = unur_distr_lomax(fpm,2);


fpm[0] = 20.;
fpm[1] = 0.4;
distr[57] = unur_distr_lomax(fpm,2);


fpm[0] = 0.2;
fpm[1] = 40.;
distr[58] = unur_distr_lomax(fpm,2);


fpm[0] = 0.2;
fpm[1] = 0.5;
distr[59] = unur_distr_lomax(fpm,2);


distr[17] = unur_distr_normal(NULL,0);


fpm[0] = 1.;
fpm[1] = 1.e-5;
distr[18] = unur_distr_normal(fpm,2);


fpm[0] = 0.;
fpm[1] = 1.e+5;
distr[19] = unur_distr_normal(fpm,2);


fpm[0] = 2.;
fpm[1] = 3.;
distr[52] = unur_distr_pareto(fpm,2);


fpm[0] = 20.;
fpm[1] = 0.4;
distr[53] = unur_distr_pareto(fpm,2);


fpm[0] = 0.2;
fpm[1] = 40.;
distr[54] = unur_distr_pareto(fpm,2);


fpm[0] = 0.2;
fpm[1] = 0.5;
distr[55] = unur_distr_pareto(fpm,2);


fpm[0] = 0.5;
distr[42] = unur_distr_powerexponential(fpm,1);


fpm[0] = 1.;
distr[43] = unur_distr_powerexponential(fpm,1);


fpm[0] = 2.;
distr[44] = unur_distr_powerexponential(fpm,1);


fpm[0] = 10.;
distr[45] = unur_distr_powerexponential(fpm,1);


fpm[0] = 0.7;
distr[46] = unur_distr_triangular(fpm,1);


fpm[0] = 0.;
distr[47] = unur_distr_triangular(fpm,1);


fpm[0] = 1.;
distr[48] = unur_distr_triangular(fpm,1);


distr[20] = unur_distr_uniform(NULL,0);


fpm[0] = 1.;
fpm[1] = 20.;
distr[21] = unur_distr_uniform(fpm,2);


fpm[0] = 3.;
distr[49] = unur_distr_weibull(fpm,1);


fpm[0] = 0.5;
fpm[1] = 3.;
distr[50] = unur_distr_weibull(fpm,2);


fpm[0] = 1.5;
fpm[1] = 2.;
fpm[2] = -5.;
distr[51] = unur_distr_weibull(fpm,3);


distr[22] = unur_distr_cauchy(NULL,0);
unur_distr_cont_set_domain(distr[22],0.1,1.);
unur_distr_cont_upd_mode(distr[22]);
unur_distr_cont_upd_pdfarea(distr[22]);


	printf("\n(chi^2) "); fflush(stdout);

/* chi^2 tests: 780 */

	unur_set_default_debug(~UNUR_DEBUG_SAMPLE);
	fprintf( TESTLOG,"\nChi^2 Test:\n");

/* distribution [7] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[7]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[7]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[7]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [8] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[8]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[8]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[8]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [23] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[23]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '-' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [24] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[24]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[24]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [25] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[25]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [26] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[26]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[26]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [27] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[27]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[27]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[27]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [28] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[28]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[28]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[28]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [29] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[29]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[29]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[29]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [30] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[30]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[30]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[30]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [31] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[31]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[31]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[31]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [32] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[32]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[32]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[32]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [33] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[33]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[33]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[33]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [34] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[34]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[34]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[34]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [35] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[35]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[35]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[35]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [9] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[9]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[9]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[9]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [10] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[10]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[10]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[10]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [11] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[11]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[11]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[11]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [12] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[12]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[12]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[12]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [13] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[13]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[13]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[13]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [14] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[14]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[14]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[14]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [15] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[15]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[15]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[15]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [16] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[16]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[16]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[16]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [63] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[63]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[63]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[63]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [64] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[64]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[64]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[64]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [36] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[36]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[36]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[36]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [37] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[37]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[37]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[37]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [38] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[38]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[38]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[38]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [39] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[39]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[39]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[39]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [40] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[40]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[40]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[40]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [41] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[41]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[41]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[41]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [56] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[56]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[56]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[56]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [57] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[57]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[57]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[57]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [58] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[58]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[58]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[58]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [59] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[59]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[59]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[59]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [17] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '/' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,3)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,4)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,5)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,6)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,7)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '/' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [18] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '/' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,3)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,4)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,5)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,6)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,7)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[18]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [19] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '/' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,3)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,4)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,5)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,6)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,7)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '/' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [52] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[52]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[52]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [53] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[53]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[53]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [54] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[54]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[54]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [55] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[55]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[55]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[55]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [42] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[42]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '-' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [43] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[43]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[43]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [44] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[44]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [45] */

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[45]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [46] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[46]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[46]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [47] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[47]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[47]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [48] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[48]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[48]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [49] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[49]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[49]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[49]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [50] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[50]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[50]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[50]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [51] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[51]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[51]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[51]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [20] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[20]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[20]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[20]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [21] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[21]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[21]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [22] */

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[22]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[22]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_truncated(gen,0.5,0.55);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_cstd_new(distr[22]);
fpm[0] = 2.;
fpm[1] = 5.;
	gen = unur_init(par);
	if (gen) {
unur_cstd_chg_pdfparams(gen,fpm,2);
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("\n(timing) "); fflush(stdout);

/* timing tests: 780 */

	unur_set_default_debug(0u);
{
	double time_setup, time_sample;
	double timing_result_setup[12];
	double timing_result_marginal[12];
	int i;

	fprintf( TESTLOG,"\nTimings (setup / marginal generation times in micro seconds):\n");
	for (i=0; i<12; i++)
		fprintf( TESTLOG, "  [    %1d    ]  ", i);
	fprintf( TESTLOG,"\n");
/* distribution [0] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[0]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,2,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[0], timing_result_setup, timing_result_marginal, 12 );

/* distribution [1] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[1]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,2,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[1], timing_result_setup, timing_result_marginal, 12 );

/* distribution [2] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[2]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,2,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[2], timing_result_setup, timing_result_marginal, 12 );

/* distribution [3] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[3]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,2,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[3], timing_result_setup, timing_result_marginal, 12 );

/* distribution [4] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[4]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,2,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[4], timing_result_setup, timing_result_marginal, 12 );

/* distribution [5] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[5]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,2,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[5], timing_result_setup, timing_result_marginal, 12 );

/* distribution [6] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[6]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,2,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[6], timing_result_setup, timing_result_marginal, 12 );

/* distribution [7] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[7]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[7], timing_result_setup, timing_result_marginal, 12 );

/* distribution [8] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[8]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[8], timing_result_setup, timing_result_marginal, 12 );

/* distribution [9] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[9]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,3,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[9]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[9]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[9], timing_result_setup, timing_result_marginal, 12 );

/* distribution [10] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[10]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,3,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[10]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[10]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[10], timing_result_setup, timing_result_marginal, 12 );

/* distribution [11] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[11]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,3,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[11]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[11]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[11], timing_result_setup, timing_result_marginal, 12 );

/* distribution [12] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[12]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,3,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[12]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[12]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[12], timing_result_setup, timing_result_marginal, 12 );

/* distribution [13] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[13]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,3,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[13]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[13]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[13], timing_result_setup, timing_result_marginal, 12 );

/* distribution [14] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[14]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,3,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[14]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[14]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[14], timing_result_setup, timing_result_marginal, 12 );

/* distribution [15] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[15]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,3,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[15]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[15]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[15], timing_result_setup, timing_result_marginal, 12 );

/* distribution [16] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[16]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,3,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[16]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[16]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[16], timing_result_setup, timing_result_marginal, 12 );

/* distribution [17] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,3)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[3] = time_setup;
	if (gen) timing_result_marginal[3] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,4)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[4] = time_setup;
	if (gen) timing_result_marginal[4] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,5)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[5] = time_setup;
	if (gen) timing_result_marginal[5] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,6)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[6] = time_setup;
	if (gen) timing_result_marginal[6] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[17]);
if (!unur_cstd_set_variant(par,7)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[7] = time_setup;
	if (gen) timing_result_marginal[7] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[17], timing_result_setup, timing_result_marginal, 12 );

/* distribution [18] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,3)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[3] = time_setup;
	if (gen) timing_result_marginal[3] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,4)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[4] = time_setup;
	if (gen) timing_result_marginal[4] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,5)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[5] = time_setup;
	if (gen) timing_result_marginal[5] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,6)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[6] = time_setup;
	if (gen) timing_result_marginal[6] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[18]);
if (!unur_cstd_set_variant(par,7)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[7] = time_setup;
	if (gen) timing_result_marginal[7] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[18], timing_result_setup, timing_result_marginal, 12 );

/* distribution [19] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,1)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[1] = time_setup;
	if (gen) timing_result_marginal[1] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,2)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[2] = time_setup;
	if (gen) timing_result_marginal[2] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,3)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[3] = time_setup;
	if (gen) timing_result_marginal[3] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,4)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[4] = time_setup;
	if (gen) timing_result_marginal[4] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,5)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[5] = time_setup;
	if (gen) timing_result_marginal[5] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,6)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[6] = time_setup;
	if (gen) timing_result_marginal[6] = time_sample;
	unur_free(gen);

	unur_errno = 0;
par = unur_cstd_new(distr[19]);
if (!unur_cstd_set_variant(par,7)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[7] = time_setup;
	if (gen) timing_result_marginal[7] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[19], timing_result_setup, timing_result_marginal, 12 );

/* distribution [20] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[20]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[20], timing_result_setup, timing_result_marginal, 12 );

/* distribution [21] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	unur_errno = 0;
par = unur_cstd_new(distr[21]);
if (!unur_cstd_set_variant(par,UNUR_STDGEN_INVERSION)) { if (par) free(par); par = NULL; }
	gen = unur_test_timing(par,5,&time_setup,&time_sample,0,TESTLOG);
	if (gen) timing_result_setup[0] = time_setup;
	if (gen) timing_result_marginal[0] = time_sample;
	unur_free(gen);

	print_timing_results( TESTLOG, 0, distr[21], timing_result_setup, timing_result_marginal, 12 );

/* distribution [22] */

	for (i=0; i<12; i++) timing_result_setup[i] = -1.;
	for (i=0; i<12; i++) timing_result_marginal[i] = -1.;
	print_timing_results( TESTLOG, 0, distr[22], timing_result_setup, timing_result_marginal, 12 );

}

/* free distributions */
	unur_distr_free(distr[0]);
	unur_distr_free(distr[1]);
	unur_distr_free(distr[2]);
	unur_distr_free(distr[3]);
	unur_distr_free(distr[4]);
	unur_distr_free(distr[5]);
	unur_distr_free(distr[6]);
	unur_distr_free(distr[7]);
	unur_distr_free(distr[8]);
	unur_distr_free(distr[9]);
	unur_distr_free(distr[10]);
	unur_distr_free(distr[11]);
	unur_distr_free(distr[12]);
	unur_distr_free(distr[13]);
	unur_distr_free(distr[14]);
	unur_distr_free(distr[15]);
	unur_distr_free(distr[16]);
	unur_distr_free(distr[17]);
	unur_distr_free(distr[18]);
	unur_distr_free(distr[19]);
	unur_distr_free(distr[20]);
	unur_distr_free(distr[21]);
	unur_distr_free(distr[22]);
	unur_distr_free(distr[23]);
	unur_distr_free(distr[24]);
	unur_distr_free(distr[25]);
	unur_distr_free(distr[26]);
	unur_distr_free(distr[27]);
	unur_distr_free(distr[28]);
	unur_distr_free(distr[29]);
	unur_distr_free(distr[30]);
	unur_distr_free(distr[31]);
	unur_distr_free(distr[32]);
	unur_distr_free(distr[33]);
	unur_distr_free(distr[34]);
	unur_distr_free(distr[35]);
	unur_distr_free(distr[36]);
	unur_distr_free(distr[37]);
	unur_distr_free(distr[38]);
	unur_distr_free(distr[39]);
	unur_distr_free(distr[40]);
	unur_distr_free(distr[41]);
	unur_distr_free(distr[42]);
	unur_distr_free(distr[43]);
	unur_distr_free(distr[44]);
	unur_distr_free(distr[45]);
	unur_distr_free(distr[46]);
	unur_distr_free(distr[47]);
	unur_distr_free(distr[48]);
	unur_distr_free(distr[49]);
	unur_distr_free(distr[50]);
	unur_distr_free(distr[51]);
	unur_distr_free(distr[52]);
	unur_distr_free(distr[53]);
	unur_distr_free(distr[54]);
	unur_distr_free(distr[55]);
	unur_distr_free(distr[56]);
	unur_distr_free(distr[57]);
	unur_distr_free(distr[58]);
	unur_distr_free(distr[59]);
	unur_distr_free(distr[60]);
	unur_distr_free(distr[61]);
	unur_distr_free(distr[62]);
	unur_distr_free(distr[63]);
	unur_distr_free(distr[64]);
#if WITH_DMALLOC
	dmalloc_vmessage("section = validate  ================================\n","");
	dmalloc_log_unfreed();
#endif


	/* test finished */
	if (n_tests_failed>0) n_tests_failed--;  /* we accept one failure */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" --> failed] ") : printf(" --> ok] ");

} /* end of test_validate */

/*---------------------------------------------------------------------------*/




/*---------------------------------------------------------------------------*/
/* run generator in verifying mode */

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par )
{
	UNUR_GEN *gen;
	int i;

	/* switch to verifying mode */
	unur_cstd_set_verify(par,1);

	/* initialize generator */
	gen = unur_init( par ); abort_if_NULL(LOG, line, gen);

	/* run generator */
	for (i=0; i<VIOLATE_SAMPLE_SIZE; i++)
		unur_sample_cont(gen);

	/* destroy generator */
	unur_free(gen); 

} /* end of run_verify_generator() */

int unur_cstd_set_verify(UNUR_PAR *par, int verify) {return 0;}
/*---------------------------------------------------------------------------*/
#else
/*---------------------------------------------------------------------------*/
int main() { exit(77); } /* ignore test */
/*---------------------------------------------------------------------------*/
#endif  /* T_CSTD */
/*---------------------------------------------------------------------------*/
