/*
	file automatically generated by make_test_files.pl
	Fri Jun 14 15:21:43 2002
*/

/*****************************************************************************
 *                                                                           *
 *          UNURAN -- Universal Non-Uniform Random number generator          *
 *                                                                           *
 *****************************************************************************/
    
/**
 ** Tests for DSROU
 **/
    
/*---------------------------------------------------------------------------*/
#include "testunuran.h"
/*---------------------------------------------------------------------------*/
#ifdef T_DSROU
/*---------------------------------------------------------------------------*/

/*---------------------------------------------------------------------------*/
/* global variables                                                          */

static struct prng *urng;           /* uniform random number generator       */

static FILE *TESTLOG;               /* test log file                         */
static FILE *UNURANLOG;             /* unuran log file                       */

static int test_ok = TRUE;          /* all tests ok (boolean)                */
static int n_tests_failed;          /* number of failed tests                */

/*---------------------------------------------------------------------------*/

void test_new( void );
void test_set( void );
void test_get( void );
void test_chg( void );
void test_init( void );
void test_reinit( void );
void test_sample( void );
void test_validate( void );

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par );

int unur_dsrou_set_verify( UNUR_PAR *par, int );

/*---------------------------------------------------------------------------*/


/* prototypes */
int unur_dsrou_set_pedantic( struct unur_par *par, int pedantic );

double pmf( int k, UNUR_DISTR *distr );


double pdf( double x, UNUR_DISTR *distr );
double pdf_sqrtlin( double x, UNUR_DISTR *distr );
double dpdf_sqrtlin( double x, UNUR_DISTR *distr );
double cdf_sqrtlin( double x, UNUR_DISTR *distr );
double pdf_sqrtlinshft(double x, UNUR_DISTR *distr );
double dpdf_sqrtlinshft( double x, UNUR_DISTR *distr );
double cdf_sqrtlinshft( double x, UNUR_DISTR *distr );



static int COMPARE_SAMPLE_SIZE = 10000;
static int VIOLATE_SAMPLE_SIZE = 20;





/*---------------------------------------------------------------------------*/

int main()
{ 
	/* open log file for unuran and set output stream for unuran messages */
	UNURANLOG = fopen( "t_dsrou_unuran.log","w" );
	abort_if_NULL( stderr,-1, UNURANLOG );
	unur_set_stream( UNURANLOG );

	/* open log file for testing */
	TESTLOG = fopen( "t_dsrou_test.log","w" );
	abort_if_NULL( stderr,-1, TESTLOG );

	/* write header into log file */
  	{
		time_t started;  
		fprintf(TESTLOG,"\nUNURAN - Universal Non-Uniform RANdom number generator\n\n");
		if (time( &started ) != -1)
			fprintf(TESTLOG,"%s",ctime(&started));
		fprintf(TESTLOG,"\n====================================================\n\n");
	}

	/* set uniform random number generator */
	urng = prng_new("mt19937(82456)");
	unur_set_default_urng(urng);

	/* set default debugging flag */
	unur_set_default_debug(UNUR_DEBUG_ALL);

	/* start test */
	printf("dsrou: ");

	/* run tests */
	test_new();
	test_set();
	test_get();
	test_chg();
	test_init();
	test_sample();
	test_reinit();
	test_validate();

	/* test finished */
	printf("\n");  fflush(stdout);

	/* close log files */
	fprintf(TESTLOG,"\n====================================================\n\n");
	if (test_ok)
		fprintf(TESTLOG,"All tests PASSED.\n");
	else
		fprintf(TESTLOG,"Test(s) FAILED.\n");

	fclose(UNURANLOG);
	fclose(TESTLOG);

	/* exit */
	exit( (test_ok) ? 0 : -1 );

} /* end of main */

/*---------------------------------------------------------------------------*/

void test_new (void)
{
	/* start test */
	printf("[new "); fflush(stdout);
	fprintf(TESTLOG,"\n[new]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_DISTR *distr = NULL;
   distr = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 45, (unur_dsrou_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 45, UNUR_ERR_NULL );
unur_distr_free(distr);
}

/* invalid distribution type */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_cont_new(); 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 51, (unur_dsrou_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 51, UNUR_ERR_DISTR_INVALID );
unur_distr_free(distr);
}

/* data missing in distribution object */
{
UNUR_DISTR *distr = NULL;
   distr = unur_distr_discr_new(); 

unur_errno = 0;
/* pmf, mode, pmfsum */
n_tests_failed += check_expected_NULL( TESTLOG, 58, (unur_dsrou_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 58, UNUR_ERR_DISTR_REQUIRED );

unur_errno = 0;
/* mode, pmfsum */
unur_distr_discr_set_pmf(distr,pmf);
n_tests_failed += check_expected_NULL( TESTLOG, 63, (unur_dsrou_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 63, UNUR_ERR_DISTR_REQUIRED );

unur_errno = 0;
/* pmfsum */
unur_distr_discr_set_mode(distr,0);
n_tests_failed += check_expected_NULL( TESTLOG, 68, (unur_dsrou_new( distr )) );
n_tests_failed += check_errorcode( TESTLOG, 68, UNUR_ERR_DISTR_REQUIRED );
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = new  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_new() */

/*---------------------------------------------------------------------------*/

void test_set (void)
{
	/* start test */
	printf("[set "); fflush(stdout);
	fprintf(TESTLOG,"\n[set]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_PAR   *par = NULL;
   par = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 78, (unur_dsrou_set_cdfatmode(par,0.)) );
n_tests_failed += check_errorcode( TESTLOG, 78, UNUR_ERR_NULL );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 81, (unur_dsrou_set_verify(par,1)) );
n_tests_failed += check_errorcode( TESTLOG, 81, UNUR_ERR_NULL );
}

/* invalid parameter object */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double fpar[2] = {10,0.63};
   distr = unur_distr_binomial(fpar,2);
   par = unur_dari_new(distr); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 89, (unur_dsrou_set_cdfatmode(par,0.)) );
n_tests_failed += check_errorcode( TESTLOG, 89, UNUR_ERR_PAR_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 92, (unur_dsrou_set_verify(par,1)) );
n_tests_failed += check_errorcode( TESTLOG, 92, UNUR_ERR_PAR_INVALID );
free(par);
unur_distr_free(distr);
}

/* invalid parameters */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double fpar[2] = {10.,0.63};
   distr = unur_distr_binomial(fpar,2);
   par = unur_dsrou_new(distr); 

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 102, (unur_dsrou_set_cdfatmode(par,-1.)) );
n_tests_failed += check_errorcode( TESTLOG, 102, UNUR_ERR_PAR_SET );
free(par);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = set  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_set() */

/*---------------------------------------------------------------------------*/

void test_get (void)
{
	/* start test */
	printf("[get "); fflush(stdout);
	fprintf(TESTLOG,"\n[get]\n");

	/* reset counter */
	n_tests_failed = 0;
  

	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = get  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_get() */

/*---------------------------------------------------------------------------*/

void test_chg (void)
{
	/* start test */
	printf("[chg "); fflush(stdout);
	fprintf(TESTLOG,"\n[chg]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid generator object */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double fpar[2] = {10.,0.63};
   distr = unur_distr_binomial(fpar,2);
   par = unur_dari_new(distr);
   unur_set_debug(par,0);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 119,    gen );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 122, (unur_dsrou_chg_verify(gen,1)) );
n_tests_failed += check_errorcode( TESTLOG, 122, UNUR_ERR_GEN_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 125, (unur_dsrou_chg_domain(gen,0,5)) );
n_tests_failed += check_errorcode( TESTLOG, 125, UNUR_ERR_GEN_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 128, (unur_dsrou_chg_mode(gen,6)) );
n_tests_failed += check_errorcode( TESTLOG, 128, UNUR_ERR_GEN_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 131, (unur_dsrou_chg_cdfatmode(gen,1.)) );
n_tests_failed += check_errorcode( TESTLOG, 131, UNUR_ERR_GEN_INVALID );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 134, (unur_dsrou_chg_pmfsum(gen,1.)) );
n_tests_failed += check_errorcode( TESTLOG, 134, UNUR_ERR_GEN_INVALID );
unur_free(gen);
unur_distr_free(distr);
}

/* invalid parameters */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double fpar[2] = {10.,0.63};
   distr = unur_distr_binomial(fpar,2);
   par = unur_dsrou_new(distr);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 140,    gen );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 143, (unur_dsrou_chg_pmfparams(gen,NULL,1)) );
n_tests_failed += check_errorcode( TESTLOG, 143, UNUR_ERR_NULL );

unur_errno = 0;
unur_dsrou_chg_pmfparams(gen,fpar,UNUR_DISTR_MAXPARAMS+10);
n_tests_failed += check_errorcode( TESTLOG, 146, UNUR_ERR_DISTR_NPARAMS );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 149, (unur_dsrou_chg_pmfparams(gen,fpar,-1)) );
n_tests_failed += check_errorcode( TESTLOG, 149, UNUR_ERR_DISTR_NPARAMS );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 152, (unur_dsrou_chg_cdfatmode(gen,-1.)) );
n_tests_failed += check_errorcode( TESTLOG, 152, UNUR_ERR_PAR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 155, (unur_dsrou_chg_domain(gen,1.,-1.)) );
n_tests_failed += check_errorcode( TESTLOG, 155, UNUR_ERR_DISTR_SET );

unur_errno = 0;
n_tests_failed += check_expected_setfailed( TESTLOG, 158, (unur_dsrou_chg_pmfsum(gen,-1.)) );
n_tests_failed += check_errorcode( TESTLOG, 158, UNUR_ERR_DISTR_SET );
unur_free(gen);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = chg  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_chg() */

/*---------------------------------------------------------------------------*/

void test_init (void)
{
	/* start test */
	printf("[init "); fflush(stdout);
	fprintf(TESTLOG,"\n[init]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* invalid NULL ptr */
{
UNUR_PAR   *par = NULL;
   par = NULL; 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 168, (unur_init( par )) );
n_tests_failed += check_errorcode( TESTLOG, 168, UNUR_ERR_NULL );
}

/* invalid data */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   distr = unur_distr_discr_new();
   unur_distr_discr_set_pmf(distr,pmf);
   unur_distr_discr_set_mode(distr,2);
   unur_distr_discr_set_pmfsum(distr,1.);
   par = unur_dsrou_new(distr); 

unur_errno = 0;
n_tests_failed += check_expected_NULL( TESTLOG, 179, (unur_init( par )) );
n_tests_failed += check_errorcode( TESTLOG, 179, UNUR_ERR_GEN_DATA );
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = init  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_init() */

/*---------------------------------------------------------------------------*/

void test_reinit (void)
{
	/* start test */
	printf("[reinit "); fflush(stdout);
	fprintf(TESTLOG,"\n[reinit]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* exist */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
UNUR_GEN   *gen = NULL;
   double fpar[2] = {10.,0.63};
   distr = unur_distr_binomial(fpar,2);
   par = unur_dsrou_new(distr);
   gen = unur_init( par ); 
abort_if_NULL(TESTLOG, 189,    gen );

unur_errno = 0;
n_tests_failed += check_expected_reinit( TESTLOG, 192, (unur_dsrou_reinit( gen )) );
unur_free(gen);
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = reinit  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_reinit() */

/*---------------------------------------------------------------------------*/

void test_sample (void)
{
	/* start test */
	printf("[sample "); fflush(stdout);
	fprintf(TESTLOG,"\n[sample]\n");

	/* reset counter */
	n_tests_failed = 0;
  
/* compare */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double fpar[2] = {10.,0.63};
   distr = unur_distr_binomial(fpar,2);
   par = NULL; 

unur_errno = 0;
/* default algorithm */
par = unur_dsrou_new(distr);
n_tests_failed += compare_int_sequence_par_start( TESTLOG, 205, urng, par, COMPARE_SAMPLE_SIZE );

unur_errno = 0;
/* default algorithm - verifying mode */
par = unur_dsrou_new(distr);
unur_dsrou_set_verify(par,1);
n_tests_failed += compare_int_sequence_par( TESTLOG, 210, urng, par, COMPARE_SAMPLE_SIZE );
unur_distr_free(distr);
}

/* violate condition */
{
UNUR_DISTR *distr = NULL;
UNUR_PAR   *par = NULL;
   double fpar[2] = {10.,0.63};
   distr = unur_distr_binomial(fpar,2);
   par = NULL; 

unur_errno = 0;
/* use cdf at mode */
par = unur_dsrou_new(distr);
unur_dsrou_set_cdfatmode(par,0.4);
 run_verify_generator ( TESTLOG,221, par );
n_tests_failed += check_errorcode( TESTLOG, 221, UNUR_ERR_GEN_CONDITION );
unur_distr_free(distr);
}


	/* test finished */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf("--> failed] ") : printf("--> ok] ");

#if WITH_DMALLOC
	dmalloc_vmessage("section = sample  ================================\n",NULL);
	dmalloc_log_unfreed();
#endif

} /* end of test_sample() */

/*---------------------------------------------------------------------------*/

void test_validate (void)
{
	UNUR_DISTR *distr[15];
	UNUR_PAR *par;
	UNUR_GEN *gen;
	int n_tests_failed = 0;
	double *darray;
	double fpm[10];

	/* start test */
	printf("[validate "); fflush(stdout);
	fprintf(TESTLOG,"\n[validate]\n");

	/* reset counter */
	n_tests_failed = 0;


/* distributions: 15 */
fpm[0] = 0.5;
distr[0] = unur_distr_geometric(fpm,1);


fpm[0] = 0.1;
distr[1] = unur_distr_geometric(fpm,1);


fpm[0] = 0.001;
distr[2] = unur_distr_geometric(fpm,1);


fpm[0] = 0.1;
distr[3] = unur_distr_logarithmic(fpm,1);


fpm[0] = 0.9;
distr[4] = unur_distr_logarithmic(fpm,1);


fpm[0] = 0.5;
fpm[1] = 10.;
distr[5] = unur_distr_negativebinomial(fpm,2);


fpm[0] = 0.7;
fpm[1] = 5.;
distr[6] = unur_distr_negativebinomial(fpm,2);


fpm[0] = 0.1;
fpm[1] = 20.;
distr[7] = unur_distr_negativebinomial(fpm,2);


fpm[0] = 3.;
distr[8] = unur_distr_poisson(fpm,1);


fpm[0] = 50.;
distr[9] = unur_distr_poisson(fpm,1);


fpm[0] = 2.;
fpm[1] = 1.;
distr[10] = unur_distr_zipf(fpm,2);


fpm[0] = 20.;
fpm[1] = 0.8;
distr[11] = unur_distr_binomial(fpm,2);


fpm[0] = 2000.;
fpm[1] = 0.0013;
distr[12] = unur_distr_binomial(fpm,2);


fpm[0] = 2000.;
fpm[1] = 200.;
fpm[2] = 20;
distr[13] = unur_distr_hypergeometric(fpm,3);


fpm[0] = 2000.;
fpm[1] = 200.;
fpm[2] = 220;
distr[14] = unur_distr_hypergeometric(fpm,3);


	printf("\n(chi^2) "); fflush(stdout);

/* chi^2 tests: 60 */

	unur_set_default_debug(~UNUR_DEBUG_SAMPLE);
	fprintf( TESTLOG,"\nChi^2 Test:\n");

/* distribution [0] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[0]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[0]), distr[0] );
par = unur_dsrou_new(distr[0]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[0]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [1] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[1]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[1]), distr[1] );
par = unur_dsrou_new(distr[1]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[1]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [2] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[2]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[2]), distr[2] );
par = unur_dsrou_new(distr[2]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[2]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [3] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[3]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[3]), distr[3] );
par = unur_dsrou_new(distr[3]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [4] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[4]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[4]), distr[4] );
par = unur_dsrou_new(distr[4]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[4]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [5] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[5]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[5]), distr[5] );
par = unur_dsrou_new(distr[5]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[5]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [6] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[6]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[6]), distr[6] );
par = unur_dsrou_new(distr[6]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[6]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [7] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[7]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[7]), distr[7] );
par = unur_dsrou_new(distr[7]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [8] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[8]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[8]), distr[8] );
par = unur_dsrou_new(distr[8]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[8]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [9] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[9]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[9]), distr[9] );
par = unur_dsrou_new(distr[9]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[9]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [11] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[11]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[11]), distr[11] );
par = unur_dsrou_new(distr[11]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[11]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[11]);
fpm[0] = 10.;
fpm[1] = 0.63;
	gen = unur_init(par);
	if (gen) {
unur_srou_chg_pdfparams(gen,fpm,2);
unur_srou_upd_pdfarea(gen);
unur_srou_upd_mode(gen);
unur_srou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [12] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[12]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[12]), distr[12] );
par = unur_dsrou_new(distr[12]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[12]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[12]);
fpm[0] = 10.;
fpm[1] = 0.63;
	gen = unur_init(par);
	if (gen) {
unur_srou_chg_pdfparams(gen,fpm,2);
unur_srou_upd_pdfarea(gen);
unur_srou_upd_mode(gen);
unur_srou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

/* distribution [13] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[13]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[13]), distr[13] );
par = unur_dsrou_new(distr[13]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[13]);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

/* distribution [14] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[14]);
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[14]), distr[14] );
par = unur_dsrou_new(distr[14]);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	n_tests_failed += run_validate_chi2( TESTLOG, 0, gen, '+' );
	unur_free(gen);
	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

	printf("\n(verify hat) "); fflush(stdout);

/* verify hat tests: 60 */

	unur_set_default_debug(~UNUR_DEBUG_SAMPLE);
	fprintf( TESTLOG,"\nVerify Hat Test (squeeze <= PDF <= hat):\n");

/* distribution [0] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[0]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[0]), distr[0] );
par = unur_dsrou_new(distr[0]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[0]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

/* distribution [1] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[1]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[1]), distr[1] );
par = unur_dsrou_new(distr[1]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[1]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

/* distribution [2] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[2]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[2]), distr[2] );
par = unur_dsrou_new(distr[2]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[2]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

/* distribution [3] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[3]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[3]), distr[3] );
par = unur_dsrou_new(distr[3]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [4] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[4]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[4]), distr[4] );
par = unur_dsrou_new(distr[4]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[4]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

/* distribution [5] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[5]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[5]), distr[5] );
par = unur_dsrou_new(distr[5]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[5]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

/* distribution [6] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[6]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[6]), distr[6] );
par = unur_dsrou_new(distr[6]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[6]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

/* distribution [7] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[7]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[7]), distr[7] );
par = unur_dsrou_new(distr[7]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);

/* distribution [8] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[8]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[8]), distr[8] );
par = unur_dsrou_new(distr[8]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[8]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

/* distribution [9] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[9]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[9]), distr[9] );
par = unur_dsrou_new(distr[9]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[9]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

/* distribution [11] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[11]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[11]), distr[11] );
par = unur_dsrou_new(distr[11]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[11]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[11]);
	unur_dsrou_set_pedantic(par,0);
fpm[0] = 10.;
fpm[1] = 0.63;
	gen = unur_init(par);
	if (gen) {
unur_srou_chg_pdfparams(gen,fpm,2);
unur_srou_upd_pdfarea(gen);
unur_srou_upd_mode(gen);
unur_srou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

/* distribution [12] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[12]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[12]), distr[12] );
par = unur_dsrou_new(distr[12]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[12]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[12]);
	unur_dsrou_set_pedantic(par,0);
fpm[0] = 10.;
fpm[1] = 0.63;
	gen = unur_init(par);
	if (gen) {
unur_srou_chg_pdfparams(gen,fpm,2);
unur_srou_upd_pdfarea(gen);
unur_srou_upd_mode(gen);
unur_srou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

/* distribution [13] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[13]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[13]), distr[13] );
par = unur_dsrou_new(distr[13]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[13]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) {
unur_dsrou_chg_domain(gen,2,7);
unur_dsrou_upd_pmfsum(gen);
unur_dsrou_upd_mode(gen);
unur_dsrou_reinit(gen);	
	}
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

/* distribution [14] */

	do {
	unur_errno = 0;
par = unur_dsrou_new(distr[14]);
	unur_dsrou_set_pedantic(par,0);
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	do {
	unur_errno = 0;
{ double Fmode = unur_distr_discr_eval_cdf( unur_distr_discr_get_mode(distr[14]), distr[14] );
par = unur_dsrou_new(distr[14]);
	unur_dsrou_set_pedantic(par,0);
unur_dsrou_set_cdfatmode(par,Fmode); }
	gen = unur_init(par);
	if (gen) unur_dsrou_chg_verify(gen,1);
	n_tests_failed += run_validate_verifyhat( TESTLOG, 0, gen, '~' );
	unur_free(gen);

	} while (0);

	printf("."); fflush(stdout);

	printf("."); fflush(stdout);


/* free distributions */
	unur_distr_free(distr[0]);
	unur_distr_free(distr[1]);
	unur_distr_free(distr[2]);
	unur_distr_free(distr[3]);
	unur_distr_free(distr[4]);
	unur_distr_free(distr[5]);
	unur_distr_free(distr[6]);
	unur_distr_free(distr[7]);
	unur_distr_free(distr[8]);
	unur_distr_free(distr[9]);
	unur_distr_free(distr[10]);
	unur_distr_free(distr[11]);
	unur_distr_free(distr[12]);
	unur_distr_free(distr[13]);
	unur_distr_free(distr[14]);
#if WITH_DMALLOC
	dmalloc_vmessage("section = validate  ================================\n","");
	dmalloc_log_unfreed();
#endif


	/* test finished */
	if (n_tests_failed>0) n_tests_failed--;  /* we accept one failure */
	test_ok &= (n_tests_failed) ? 0 : 1;
	(n_tests_failed) ? printf(" --> failed] ") : printf(" --> ok] ");

} /* end of test_validate */

/*---------------------------------------------------------------------------*/


/* pmf that does not work */
double pmf( int k, UNUR_DISTR *distr )
{ 
  return ((k==2) ? 0. : pow(0.5,k));
} /* end of pmf */

double pmf_invalidmode( int k, UNUR_DISTR *distr )
{ 
  return ((k==2) ? 0.01 : pow(0.5,k));
} /* end of pmf */


/* pdf with piecewise linear function as transformed density with T = -1/sqrt */
double pdf_sqrtlin( double x, UNUR_DISTR *distr )
{ 
	double y = 1./(fabs(x)+1.);
	return y*y;
}
double dpdf_sqrtlin( double x, UNUR_DISTR *distr )
{ 
	double y = 1./(fabs(x)+1.);
	y = 2.*y*y*y;
	return ((x<0.) ? y : - y);
}
double cdf_sqrtlin( double x, UNUR_DISTR *distr )
{ 
	if (x<=0.)
		return 0.5/(1.-x);
	else
		return (1.-0.5/(1.+x));
}

/* pdf with piecewise linear function as transformed density with T = -1/sqrt and shifted mode */
double pdf_sqrtlinshft( double x, UNUR_DISTR *distr )
{ 
	double y;
	x -= 1000.;
	y = 1./(fabs(x)+1.);
	return y*y;
}
double dpdf_sqrtlinshft( double x, UNUR_DISTR *distr )
{ 
	double y;
	x -= 1000.;
	y = 1./(fabs(x)+1.);
	y = 2.*y*y*y;
	return ((x<0.) ? y : - y);
}
double cdf_sqrtlinshft( double x, UNUR_DISTR *distr )
{ 
	x -= 1000.;
	if (x<=0.)
		return 0.5/(1.-x);
	else
		return (1.-0.5/(1.+x));
}

/* no such function */
int unur_dsrou_set_pedantic( struct unur_par *par, int pedantic )
{ return 1; }



/*---------------------------------------------------------------------------*/
/* run generator in verifying mode */

void run_verify_generator( FILE *LOG, int line, UNUR_PAR *par )
{
	UNUR_GEN *gen;
	int i;

	/* switch to verifying mode */
	unur_dsrou_set_verify(par,1);

	/* initialize generator */
	gen = unur_init( par ); abort_if_NULL(LOG, line, gen);

	/* run generator */
	for (i=0; i<VIOLATE_SAMPLE_SIZE; i++)
		unur_sample_cont(gen);

	/* destroy generator */
	unur_free(gen); 

} /* end of run_verify_generator() */

/*---------------------------------------------------------------------------*/
#else
/*---------------------------------------------------------------------------*/
int main() { exit(77); } /* ignore test */
/*---------------------------------------------------------------------------*/
#endif  /* T_DSROU */
/*---------------------------------------------------------------------------*/
